@@ -48,6 +48,8 @@ class DataAnalyzer(object):
             self.nuisance_parameters,
             self.n_events_generated_per_benchmark,
             self.n_events_backgrounds,
+            self.finite_difference_benchmarks,
+            self.finite_difference_epsilon,
         ) = load_madminer_settings(filename, include_nuisance_benchmarks=include_nuisance_parameters)
 
         self.n_parameters = len(self.parameters)
@@ -296,7 +298,6 @@ class DataAnalyzer(object):
         # Inputs
         if thetas is not None:
             include_nuisance_benchmarks = True
-
         if thetas is not None:
             if nus is None:
                 nus = [None for _ in thetas]
@@ -512,20 +513,13 @@ class DataAnalyzer(object):
 
     def _report_setup(self):
         logger.info("Found %s parameters", self.n_parameters)
-        for key, values in six.iteritems(self.parameters):
-            logger.debug(
-                "   %s (LHA: %s %s, maximal power in squared ME: %s, range: %s)",
-                key,
-                values[0],
-                values[1],
-                values[2],
-                values[3],
-            )
+        for i, (key, values) in enumerate(six.iteritems(self.parameters)):
+            logger.info("  %s: %s (%s)", i, key, " / ".join(str(x) for x in values))
 
         if self.nuisance_parameters is not None:
             logger.info("Found %s nuisance parameters", self.n_nuisance_parameters)
-            for key, values in six.iteritems(self.nuisance_parameters):
-                logger.debug("   %s (%s)", key, values)
+            for i, (key, values) in enumerate(six.iteritems(self.systematics)):
+                logger.info("  %s: %s (%s)", i, key, " / ".join(str(x) for x in values))
         else:
             logger.info("Did not find nuisance parameters")
             self.include_nuisance_parameters = False
@@ -570,6 +564,37 @@ class DataAnalyzer(object):
         else:
             return 1.0
 
+    def _finite_differences_theta_gradient_matrices(self):
+        """ Constructs the matrix that translates benchmark weights to the gradient of the weight evaluated at the benchmarks """
+        assert self.finite_difference_benchmarks is not None
+        assert self.finite_difference_epsilon is not None
+
+        matrix = np.zeros(
+            (self.n_benchmarks, self.n_parameters, self.n_benchmarks)
+        )  # (n_thetas, n_gradients, n_benchmarks)
+        benchmark_names = list(six.iterkeys(self.benchmarks))
+
+        # We'll generally try to find the tupels p, i, j, k such that matrix[i, p, j] = - 1 / eps and matrix[i, p, i] = 1 / eps
+
+        for i, benchmark in enumerate(six.iterkeys(self.benchmarks)):
+            # For the FD-shited benchmarks, we assume that the gradients are the same as at the original point, and will just copy the matrix later
+            copy_to = []
+            if benchmark not in self.finite_difference_benchmarks:
+                continue
+
+            for p, param in enumerate(six.iterkeys(self.parameters)):
+                shifted_benchmark = self.finite_difference_benchmarks[benchmark][param]
+                j = benchmark_names.index(shifted_benchmark)
+                copy_to.append(j)
+
+                matrix[i, p, j] = 1.0 / self.finite_difference_epsilon
+                matrix[i, p, i] = -1.0 / self.finite_difference_epsilon
+
+            for j in copy_to:
+                matrix[j, :, :] = matrix[i, :, :]
+
+        return matrix
+
     @staticmethod
     def _any_nontrivial_nus(nus):
         if nus is None:
@@ -579,6 +604,17 @@ class DataAnalyzer(object):
                 return True
         return False
 
+    def _derivative_mode(self):
+        if self.morpher is not None:
+            mode = "morphing"
+        elif self.finite_difference_benchmarks is not None:
+            mode = "fd"
+        else:
+            raise RuntimeError(
+                "Cannot compute xsec gradients when neither morphing nor finite differences are correctly set up!"
+            )
+        return mode
+
     def _weights(self, thetas, nus, benchmark_weights, theta_matrices=None):
         """
         Turns benchmark weights into weights for given parameter points (theta, nu).
@@ -876,25 +912,36 @@ class DataAnalyzer(object):
     def _get_dtheta_benchmark_matrix(self, theta, zero_pad=True):
         """Calculates matrix A_ij such that d dsigma(theta) / d theta_i = A_ij * dsigma (benchmark j)"""
 
-        if self.morpher is None:
-            raise RuntimeError("Cannot calculate score without morphing")
+        mode = self._derivative_mode()
 
         if zero_pad:
             unpadded_theta_matrix = self._get_dtheta_benchmark_matrix(theta, zero_pad=False)
             dtheta_matrix = np.zeros((unpadded_theta_matrix.shape[0], self.n_benchmarks))
             dtheta_matrix[:, : unpadded_theta_matrix.shape[1]] = unpadded_theta_matrix
 
-        elif isinstance(theta, six.string_types):
+        elif isinstance(theta, six.string_types) and mode == "morphing":
             benchmark = self.benchmarks[theta]
             benchmark = np.array([value for _, value in six.iteritems(benchmark)])
             dtheta_matrix = self._get_dtheta_benchmark_matrix(benchmark)
 
-        elif isinstance(theta, int):
+        elif isinstance(theta, int) and mode == "morphing":
             benchmark = self.benchmarks[list(self.benchmarks.keys())[theta]]
             benchmark = np.array([value for _, value in six.iteritems(benchmark)])
             dtheta_matrix = self._get_dtheta_benchmark_matrix(benchmark)
 
+        elif isinstance(theta, six.string_types):  # finite differences
+            benchmark_id = list(six.iterkeys(self.benchmarks)).index(theta)
+            dtheta_matrix = self._get_dtheta_benchmark_matrix(benchmark_id)
+
+        elif isinstance(theta, int):  # finite differences
+            dtheta_matrix = self._finite_differences_theta_gradient_matrices()[
+                theta
+            ]  # TODO: avoid constructing the full matrix every time
+
         else:
+            if mode == "fd":
+                raise RuntimeError("Cannot calculate score for arbitrary parameter points without morphing setup")
+
             dtheta_matrix = self.morpher.calculate_morphing_weight_gradient(
                 theta
             )  # Shape (n_parameters, n_benchmarks_phys)
