@@ -2,6 +2,6 @@ from .double_parameterized_ratio import DoubleParameterizedRatioEstimator
 from .ensemble import Ensemble
 from .likelihood import LikelihoodEstimator
 from .lookup import load_estimator
-from .morphing_aware import MorphingAwareRatioEstimator
+from .morphing_aware import MorphingAwareRatioEstimator, QuadraticMorphingAwareRatioEstimator
 from .parameterized_ratio import ParameterizedRatioEstimator
 from .score import ScoreEstimator
