@@ -1,5 +1,10 @@
 from .distributions import plot_distributions, plot_histograms
-from .morphing import plot_2d_morphing_basis, plot_nd_morphing_basis_scatter, plot_nd_morphing_basis_slices
+from .morphing import (
+    plot_2d_morphing_basis,
+    plot_nd_morphing_basis_scatter,
+    plot_nd_morphing_basis_slices,
+    plot_1d_morphing_basis,
+)
 from .fisherinformation import (
     plot_fisherinfo_barplot,
     plot_fisher_information_contours_2d,
